@@ -44,9 +44,6 @@ The `plot` module provides the following features:
     Module :py:mod:`guiqwt.panels`
         Module providing the `plot panels` IDs
         
-    Module :py:mod:`guiqwt.signals`
-        Module providing all the end-user Qt SIGNAL objects defined in `guiqwt`
-        
     Module :py:mod:`guiqwt.baseplot`
         Module providing the `guiqwt` plotting widget base class
 
@@ -56,15 +53,15 @@ Class diagrams
 
 Curve-related widgets with integrated plot manager:
 
-.. image:: images/curve_widgets.png
+.. image:: /images/curve_widgets.png
 
 Image-related widgets with integrated plot manager:
 
-.. image:: images/image_widgets.png
+.. image:: /images/image_widgets.png
 
 Building your own plot manager:
 
-.. image:: images/my_plot_manager.png
+.. image:: /images/my_plot_manager.png
 
 
 Examples
@@ -72,7 +69,7 @@ Examples
 
 Simple example *without* the `plot manager`:
 
-.. literalinclude:: ../guiqwt/tests/filtertest1.py
+.. literalinclude:: /../guiqwt/tests/filtertest1.py
    :start-after: SHOW
    :end-before: Workaround for Sphinx v0.6 bug: empty 'end-before' directive
 
@@ -82,7 +79,7 @@ even if this simple example does not justify the use of the `plot manager`
 complex applications, using the `plot manager` allows to design highly versatile
 graphical user interfaces.
 
-.. literalinclude:: ../guiqwt/tests/filtertest2.py
+.. literalinclude:: /../guiqwt/tests/filtertest2.py
    :start-after: SHOW
    :end-before: Workaround for Sphinx v0.6 bug: empty 'end-before' directive
 
@@ -108,7 +105,8 @@ from guidata.qt.QtGui import (QDialogButtonBox, QVBoxLayout, QGridLayout,
                               QToolBar, QDialog, QHBoxLayout, QMenu,
                               QActionGroup, QSplitter, QSizePolicy,
                               QApplication, QWidget, QMainWindow)
-from guidata.qt.QtCore import Qt, SIGNAL, SLOT
+from guidata.qt.QtCore import Qt
+from guidata.qt import PYQT5
 
 from guidata.configtools import get_icon
 from guidata.utils import assert_interfaces_valid
@@ -130,8 +128,6 @@ from guiqwt.tools import (SelectTool, RectZoomTool, ColormapTool, HelpTool,
                           ImageStatsTool, ExportItemDataTool, EditItemDataTool,
                           ItemCenterTool, SignalStatsTool, CopyToClipboardTool)
 from guiqwt.interfaces import IPlotManager
-from guiqwt.signals import (SIG_ITEMS_CHANGED, SIG_ACTIVE_ITEM_CHANGED,
-                            SIG_VISIBILITY_CHANGED, SIG_PLOT_AXIS_CHANGED)
 
 
 class DefaultPlotID(object):
@@ -186,9 +182,9 @@ class PlotManager(object):
             self.default_plot = plot
         plot.set_manager(self, plot_id)
         # Connecting signals
-        plot.connect(plot, SIG_ITEMS_CHANGED, self.update_tools_status)
-        plot.connect(plot, SIG_ACTIVE_ITEM_CHANGED, self.update_tools_status)
-        plot.connect(plot, SIG_PLOT_AXIS_CHANGED, self.plot_axis_changed)
+        plot.SIG_ITEMS_CHANGED.connect(self.update_tools_status)
+        plot.SIG_ACTIVE_ITEM_CHANGED.connect(self.update_tools_status)
+        plot.SIG_PLOT_AXIS_CHANGED.connect(self.plot_axis_changed)
         
     def set_default_plot(self, plot):
         """
@@ -259,8 +255,8 @@ class PlotManager(object):
         Register a tool to the manager
             * ToolKlass: tool's class (`guiqwt` builtin tools are defined in 
               module :py:mod:`guiqwt.tools`)
-            * *args: arguments sent to the tool's class
-            * **kwargs: keyword arguments sent to the tool's class
+            * args: arguments sent to the tool's class
+            * kwargs: keyword arguments sent to the tool's class
         
         Plot manager's registration sequence is the following:
             1. add plots
@@ -481,10 +477,15 @@ class PlotManager(object):
             tool.update_status(plot)
 
     def create_action(self, title, triggered=None, toggled=None,
-                      shortcut=None, icon=None, tip=None):
+                      shortcut=None, icon=None, tip=None, checkable=None,
+                      context=Qt.WindowShortcut, enabled=None):
+        """
+        Create a new QAction
+        """
         return create_action(self.main, title, triggered=triggered,
                              toggled=toggled, shortcut=shortcut,
-                             icon=icon, tip=tip)
+                             icon=icon, tip=tip, checkable=checkable,
+                             context=context, enabled=enabled)
 
     # The following methods provide some sets of tools that
     # are often registered together
@@ -516,11 +517,15 @@ class PlotManager(object):
         """
         Register only curve-related tools
         
-        .. seealso:: methods 
-        :py:meth:`guiqwt.plot.PlotManager.add_tool`
-        :py:meth:`guiqwt.plot.PlotManager.register_standard_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_other_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_image_tools`
+        .. seealso::
+            
+            :py:meth:`guiqwt.plot.PlotManager.add_tool`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_standard_tools`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_other_tools`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_image_tools`
         """
         self.add_tool(SignalStatsTool)
         self.add_tool(AntiAliasingTool)
@@ -530,11 +535,15 @@ class PlotManager(object):
         """
         Register only image-related tools
         
-        .. seealso:: methods 
-        :py:meth:`guiqwt.plot.PlotManager.add_tool`
-        :py:meth:`guiqwt.plot.PlotManager.register_standard_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_other_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_curve_tools`
+        .. seealso::
+            
+            :py:meth:`guiqwt.plot.PlotManager.add_tool`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_standard_tools`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_other_tools`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_curve_tools`
         """
         self.add_tool(ColormapTool)
         self.add_tool(ReverseYAxisTool)
@@ -553,11 +562,15 @@ class PlotManager(object):
         """
         Register other common tools
         
-        .. seealso:: methods 
-        :py:meth:`guiqwt.plot.PlotManager.add_tool`
-        :py:meth:`guiqwt.plot.PlotManager.register_standard_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_curve_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_image_tools`
+        .. seealso::
+
+            :py:meth:`guiqwt.plot.PlotManager.add_tool`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_standard_tools`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_curve_tools`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_image_tools`
         """
         self.add_tool(SaveAsTool)
         self.add_tool(CopyToClipboardTool)
@@ -568,13 +581,19 @@ class PlotManager(object):
         """
         Register standard, curve-related and other tools
         
-        .. seealso:: methods 
-        :py:meth:`guiqwt.plot.PlotManager.add_tool`
-        :py:meth:`guiqwt.plot.PlotManager.register_standard_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_other_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_curve_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_image_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_all_image_tools`
+        .. seealso::
+
+            :py:meth:`guiqwt.plot.PlotManager.add_tool`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_standard_tools`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_other_tools`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_curve_tools`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_image_tools`
+            
+            :py:meth:`guiqwt.plot.PlotManager.register_all_image_tools`
         """
         self.register_standard_tools()
         self.add_separator_tool()
@@ -582,19 +601,26 @@ class PlotManager(object):
         self.add_separator_tool()
         self.register_other_tools()
         self.add_separator_tool()
+        self.update_tools_status()
         self.get_default_tool().activate()
         
     def register_all_image_tools(self):
         """
         Register standard, image-related and other tools
         
-        .. seealso:: methods 
-        :py:meth:`guiqwt.plot.PlotManager.add_tool`
-        :py:meth:`guiqwt.plot.PlotManager.register_standard_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_other_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_curve_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_image_tools`
-        :py:meth:`guiqwt.plot.PlotManager.register_all_curve_tools`
+        .. seealso::
+
+            :py:meth:`guiqwt.plot.PlotManager.add_tool`
+
+            :py:meth:`guiqwt.plot.PlotManager.register_standard_tools`
+
+            :py:meth:`guiqwt.plot.PlotManager.register_other_tools`
+
+            :py:meth:`guiqwt.plot.PlotManager.register_curve_tools`
+
+            :py:meth:`guiqwt.plot.PlotManager.register_image_tools`
+
+            :py:meth:`guiqwt.plot.PlotManager.register_all_curve_tools`
         """
         self.register_standard_tools()
         self.add_separator_tool()
@@ -602,6 +628,7 @@ class PlotManager(object):
         self.add_separator_tool()
         self.register_other_tools()
         self.add_separator_tool()
+        self.update_tools_status()
         self.get_default_tool().activate()
         
     def synchronize_axis(self, axis, plots):
@@ -653,8 +680,9 @@ class SubplotWidget(QSplitter):
     the add_itemlist method can be called after having declared
     all the subplots
     """
-    def __init__(self, manager, parent=None):
-        QSplitter.__init__(self, Qt.Horizontal, parent)
+    def __init__(self, manager, parent=None, **kwargs):
+        super(SubplotWidget, self).__init__(parent, **kwargs)
+        self.setOrientation(Qt.Horizontal)
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.manager = manager
         self.plots = []
@@ -692,8 +720,12 @@ class BaseCurveWidget(QSplitter):
     def __init__(self, parent=None, title=None,
                  xlabel=None, ylabel=None, xunit=None, yunit=None,
                  section="plot", show_itemlist=False, gridparam=None,
-                 curve_antialiasing=None):
-        QSplitter.__init__(self, Qt.Horizontal, parent)
+                 curve_antialiasing=None, **kwargs):
+        if PYQT5:
+            super(BaseCurveWidget, self).__init__(parent, **kwargs)
+            self.setOrientation(Qt.Horizontal)
+        else:
+            QSplitter.__init__(self, Qt.Horizontal, parent)
         
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
         
@@ -712,6 +744,7 @@ class CurveWidget(BaseCurveWidget, PlotManager):
     """
     Construct a CurveWidget object: plotting widget with integrated 
     plot manager
+    
         * parent: parent widget
         * title: plot title
         * xlabel: (bottom axis title, top axis title) or bottom axis title only
@@ -724,10 +757,16 @@ class CurveWidget(BaseCurveWidget, PlotManager):
                  xlabel=None, ylabel=None, xunit=None, yunit=None,
                  section="plot", show_itemlist=False, gridparam=None,
                  panels=None):
-        BaseCurveWidget.__init__(self, parent, title,
-                                 xlabel, ylabel, xunit, yunit,
-                                 section, show_itemlist, gridparam)
-        PlotManager.__init__(self, main=self)
+        if PYQT5:
+            super(CurveWidget, self).__init__(parent=parent, title=title,
+                        xlabel=xlabel, ylabel=ylabel, xunit=xunit, yunit=yunit,
+                        section=section, show_itemlist=show_itemlist,
+                        gridparam=gridparam, main=self)
+        else:
+            BaseCurveWidget.__init__(self, parent, title,
+                                     xlabel, ylabel, xunit, yunit,
+                                     section, show_itemlist, gridparam)
+            PlotManager.__init__(self, main=self)
         
         # Configuring plot manager
         self.add_plot(self.plot)
@@ -808,6 +847,7 @@ class CurveDialog(QDialog, CurveWidgetMixin):
     """
     Construct a CurveDialog object: plotting dialog box with integrated 
     plot manager
+    
         * wintitle: window title
         * icon: window icon
         * edit: editable state
@@ -819,13 +859,18 @@ class CurveDialog(QDialog, CurveWidgetMixin):
     """
     def __init__(self, wintitle="guiqwt plot", icon="guiqwt.svg", edit=False,
                  toolbar=False, options=None, parent=None, panels=None):
-        QDialog.__init__(self, parent)
+        if not PYQT5:
+            QDialog.__init__(self, parent)
         self.edit = edit
         self.button_box = None
         self.button_layout = None
-        CurveWidgetMixin.__init__(self, wintitle=wintitle, icon=icon, 
-                                  toolbar=toolbar, options=options,
-                                  panels=panels)
+        if PYQT5:
+            super(CurveDialog, self).__init__(parent, wintitle=wintitle,
+                    icon=icon, toolbar=toolbar, options=options, panels=panels)
+        else:
+            CurveWidgetMixin.__init__(self, wintitle=wintitle, icon=icon, 
+                                      toolbar=toolbar, options=options,
+                                      panels=panels)
         self.setWindowFlags(Qt.Window)
         
     def setup_widget_layout(self):
@@ -846,14 +891,16 @@ class CurveDialog(QDialog, CurveWidgetMixin):
         This method may be overriden to customize the button box
         """
         bbox = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
-        self.connect(bbox, SIGNAL("accepted()"), SLOT("accept()"))
-        self.connect(bbox, SIGNAL("rejected()"), SLOT("reject()"))
+        bbox.accepted.connect(self.accept)
+        bbox.rejected.connect(self.reject)
         self.button_layout.addWidget(bbox)
         self.button_box = bbox
         
 class CurveWindow(QMainWindow, CurveWidgetMixin):
     """
-    Construct a CurveWindow object: plotting window with integrated plot manager
+    Construct a CurveWindow object: plotting window with integrated plot 
+    manager
+    
         * wintitle: window title
         * icon: window icon
         * toolbar: show/hide toolbar
@@ -864,10 +911,14 @@ class CurveWindow(QMainWindow, CurveWidgetMixin):
     """
     def __init__(self, wintitle="guiqwt plot", icon="guiqwt.svg",
                  toolbar=False, options=None, parent=None, panels=None):
-        QMainWindow.__init__(self, parent)
-        CurveWidgetMixin.__init__(self, wintitle=wintitle, icon=icon, 
-                                 toolbar=toolbar, options=options,
-                                 panels=panels)
+        if PYQT5:
+            super(CurveWindow, self).__init__(parent, wintitle=wintitle,
+                    icon=icon, toolbar=toolbar, options=options, panels=panels)
+        else:
+            QMainWindow.__init__(self, parent)
+            CurveWidgetMixin.__init__(self, wintitle=wintitle, icon=icon, 
+                                     toolbar=toolbar, options=options,
+                                     panels=panels)
         
     def setup_widget_layout(self):
         self.addToolBar(self.toolbar)
@@ -909,8 +960,12 @@ class BaseImageWidget(QSplitter):
                  colormap="jet", aspect_ratio=1.0, lock_aspect_ratio=True,
                  show_contrast=False, show_itemlist=False, show_xsection=False,
                  show_ysection=False, xsection_pos="top", ysection_pos="right",
-                 gridparam=None, curve_antialiasing=None):
-        QSplitter.__init__(self, Qt.Vertical, parent)
+                 gridparam=None, curve_antialiasing=None, **kwargs):
+        if PYQT5:
+            super(BaseImageWidget, self).__init__(parent, **kwargs)
+            self.setOrientation(Qt.Vertical)
+        else:
+            QSplitter.__init__(self, Qt.Vertical, parent)
         
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
         
@@ -933,7 +988,7 @@ class BaseImageWidget(QSplitter):
         self.xcsw = XCrossSection(self)
         self.xcsw.setVisible(show_xsection)
         
-        self.connect(self.xcsw, SIG_VISIBILITY_CHANGED, self.xcsw_is_visible)
+        self.xcsw.SIG_VISIBILITY_CHANGED.connect(self.xcsw_is_visible)
         
         self.xcsw_splitter = QSplitter(Qt.Vertical, self)
         if xsection_pos == "top":
@@ -942,8 +997,8 @@ class BaseImageWidget(QSplitter):
         else:
             self.xcsw_splitter.addWidget(self.plot)
             self.xcsw_splitter.addWidget(self.xcsw)
-        self.connect(self.xcsw_splitter, SIGNAL('splitterMoved(int,int)'),
-                     lambda pos, index: self.adjust_ycsw_height())
+        self.xcsw_splitter.splitterMoved.connect(
+                                 lambda pos, index: self.adjust_ycsw_height())
         
         self.ycsw_splitter = QSplitter(Qt.Horizontal, self)
         if ysection_pos == "left":
@@ -991,6 +1046,7 @@ class ImageWidget(BaseImageWidget, PlotManager):
     """
     Construct a ImageWidget object: plotting widget with integrated 
     plot manager
+    
         * parent: parent widget
         * title: plot title (string)
         * xlabel, ylabel, zlabel: resp. bottom, left and right axis titles 
@@ -1015,12 +1071,23 @@ class ImageWidget(BaseImageWidget, PlotManager):
                  show_contrast=False, show_itemlist=False, show_xsection=False,
                  show_ysection=False, xsection_pos="top", ysection_pos="right",
                  gridparam=None, panels=None):
-        BaseImageWidget.__init__(self, parent, title, xlabel, ylabel, zlabel,
-                 xunit, yunit, zunit, yreverse, colormap, aspect_ratio,
-                 lock_aspect_ratio, show_contrast, show_itemlist,
-                 show_xsection, show_ysection, xsection_pos, ysection_pos,
-                 gridparam)
-        PlotManager.__init__(self, main=self)
+        if PYQT5:
+            super(ImageWidget, self).__init__(parent=parent, title=title,
+                     xlabel=xlabel, ylabel=ylabel, zlabel=zlabel,
+                     xunit=xunit, yunit=yunit, zunit=zunit, yreverse=yreverse,
+                     colormap=colormap, aspect_ratio=aspect_ratio,
+                     lock_aspect_ratio=lock_aspect_ratio,
+                     show_contrast=show_contrast, show_itemlist=show_itemlist,
+                     show_xsection=show_xsection, show_ysection=show_ysection,
+                     xsection_pos=xsection_pos, ysection_pos=ysection_pos,
+                     gridparam=gridparam, main=self)
+        else:
+            BaseImageWidget.__init__(self, parent, title, xlabel, ylabel, zlabel,
+                     xunit, yunit, zunit, yreverse, colormap, aspect_ratio,
+                     lock_aspect_ratio, show_contrast, show_itemlist,
+                     show_xsection, show_ysection, xsection_pos, ysection_pos,
+                     gridparam)
+            PlotManager.__init__(self, main=self)
         
         # Configuring plot manager
         self.add_plot(self.plot)
@@ -1070,6 +1137,7 @@ class ImageDialog(CurveDialog, ImageWidgetMixin):
     """
     Construct a ImageDialog object: plotting dialog box with integrated 
     plot manager
+    
         * wintitle: window title
         * icon: window icon
         * edit: editable state
@@ -1084,6 +1152,7 @@ class ImageDialog(CurveDialog, ImageWidgetMixin):
 class ImageWindow(CurveWindow, ImageWidgetMixin):
     """
     Construct a ImageWindow object: plotting window with integrated plot manager
+    
         * wintitle: window title
         * icon: window icon
         * toolbar: show/hide toolbar
