@@ -10,14 +10,15 @@ SIFT, the Signal and Image Filtering Tool
 Simple signal and image processing application based on guiqwt and guidata
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, print_function
 
 SHOW = True # Show test in GUI-based test launcher
 
 from guidata.qt.QtGui import (QMainWindow, QMessageBox, QSplitter, QListWidget,
                               QVBoxLayout, QHBoxLayout, QWidget, QTabWidget,
                               QMenu, QApplication, QCursor, QFont)
-from guidata.qt.QtCore import Qt, QT_VERSION_STR, PYQT_VERSION_STR, SIGNAL
+from guidata.qt.QtCore import Qt, QT_VERSION_STR, PYQT_VERSION_STR, Signal
+from guidata.qt import PYQT5
 from guidata.qt.compat import getopenfilenames, getsavefilename
 
 import sys
@@ -44,7 +45,7 @@ from guiqwt.builder import make
 APP_NAME = _("Sift")
 APP_DESC = _("""Signal and Image Filtering Tool<br>
 Simple signal and image processing application based on guiqwt and guidata""")
-VERSION = '0.2.6'
+VERSION = '0.2.8'
 
 
 def normalize(yin, parameter='maximum'):
@@ -121,11 +122,50 @@ class SignalParamNew(DataSet):
 
 
 class ImageParam(DataSet):
+    def __init__(self, title=None, comment=None, icon=''):
+        DataSet.__init__(self, title, comment, icon)
+        self._template = None
+
+    @property
+    def size(self):
+        """Returns (width, height)"""
+        return self.data.shape[1], self.data.shape[0]
+
+    def update_metadata(self, value):
+        self.metadata = {}
+        for attr_str in dir(value):
+            if attr_str != 'GroupLength':
+                self.metadata[attr_str] = getattr(value, attr_str)
+
+    @property
+    def template(self):
+        return self._template
+    
+    @template.setter
+    def template(self, value):
+        self.update_metadata(value)
+        self._template = value
+
+    @property
+    def pixel_spacing(self):
+        if self.template is not None:
+            return self.template.PixelSpacing
+        else:
+            return None, None
+    
+    @pixel_spacing.setter
+    def pixel_spacing(self, value):
+        if self.template is not None:
+            dx, dy = value
+            self.template.PixelSpacing = [dx, dy]
+            self.update_metadata(self.template)
+
     title = StringItem(_("Title"), default=_("Untitled"))
     data = FloatArrayItem(_("Data"))
     metadata = DictItem(_("Metadata"), default=None)
     def copy_data_from(self, other, dtype=None):
         self.data = np.array(other.data, copy=True, dtype=dtype)
+        self.template = other.template
     def change_data_type(self, dtype):
         self.data = np.array(self.data, dtype=dtype)
 
@@ -149,6 +189,8 @@ class ObjectFT(QSplitter):
     """Object handling the item list, the selected item properties and plot"""
     PARAMCLASS = None
     PREFIX = None
+    SIG_OBJECT_ADDED = Signal()
+    SIG_STATUS_MESSAGE = Signal(str)
     def __init__(self, parent, plot):
         super(ObjectFT, self).__init__(Qt.Vertical, parent)
         self.plot = plot
@@ -179,12 +221,9 @@ class ObjectFT(QSplitter):
         self.properties = DataSetEditGroupBox(_("Properties"), self.PARAMCLASS)
         self.properties.setEnabled(False)
 
-        self.connect(self.listwidget, SIGNAL("currentRowChanged(int)"),
-                     self.current_item_changed)
-        self.connect(self.listwidget, SIGNAL("itemSelectionChanged()"),
-                     self.selection_changed)
-        self.connect(self.properties, SIGNAL("apply_button_clicked()"),
-                     self.properties_changed)
+        self.listwidget.currentRowChanged.connect(self.current_item_changed)
+        self.listwidget.itemSelectionChanged.connect(self.selection_changed)
+        self.properties.SIG_APPLY_BUTTON_CLICKED.connect(self.properties_changed)
         
         properties_stretched = QWidget()
         hlayout = QHBoxLayout()
@@ -300,7 +339,7 @@ class ObjectFT(QSplitter):
         self.items.append(None)
         self.refresh_list(new_current_row='last')
         self.listwidget.setCurrentRow(len(self.objects)-1)
-        self.emit(SIGNAL('object_added()'))
+        self.SIG_OBJECT_ADDED.emit()
         
     #------Edit operations
     def duplicate_object(self):
@@ -427,7 +466,7 @@ class ObjectFT(QSplitter):
             obj.data = func(orig.data, param)
     
     def compute_11(self, name, func, param=None, one_param_for_all=True,
-                   suffix=None):
+                   suffix=None, func_obj=None):
         if param is not None and one_param_for_all:
             if not param.edit(parent=self.parent()):
                 return
@@ -442,12 +481,13 @@ class ObjectFT(QSplitter):
             if suffix is not None:
                 obj.title += "|"+suffix(param)
             obj.copy_data_from(orig)
-            self.emit(SIGNAL("status_message(QString)"),
-                      _("Computing:")+" "+obj.title)
+            self.SIG_STATUS_MESSAGE.emit(_("Computing:")+" "+obj.title)
             QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
             self.repaint()
             try:
                 self.apply_11_func(obj, orig, func, param)
+                if func_obj is not None:
+                    func_obj(obj)
             except Exception as msg:
                 import traceback
                 traceback.print_exc()
@@ -455,7 +495,7 @@ class ObjectFT(QSplitter):
                                      _("Error:")+"\n%s" % str(msg))
                 return
             finally:
-                self.emit(SIGNAL("status_message(QString)"), "")
+                self.SIG_STATUS_MESSAGE.emit("")
                 QApplication.restoreOverrideCursor()
             self.add_object(obj)
         
@@ -769,9 +809,8 @@ class ImageFT(ObjectFT):
                                         triggered=self.swap_axes)
         flatfield_action = create_action(self, _("Flat-field correction"),
                                          triggered=self.flat_field_correction)
-        self.actlist_1 += [resize_action]
         self.actlist_2 += [flatfield_action]
-        self.actlist_1more += [roi_action, swapaxes_action,
+        self.actlist_1more += [roi_action, swapaxes_action, resize_action,
                                hflip_action, vflip_action,
                                rot90_action, rot270_action, rotate_action]
         add_actions(rotate_menu, [hflip_action, vflip_action,
@@ -867,8 +906,13 @@ class ImageFT(ObjectFT):
         
     def resize_image(self):
         rows = self._get_selected_rows()
-        obj = self.objects[rows[0]]
-        original_size = obj.data.shape[1], obj.data.shape[0]
+        objs = self.objects
+        for row in rows:
+            if objs[row].size != objs[rows[0]].size:
+                QMessageBox.warning(self.parent(), APP_NAME,
+                             _("Warning:")+"\n%s" % \
+                             "Selected images do not have the same size")
+        original_size = objs[rows[0]].size
         from guiqwt.widgets.resizedialog import ResizeDialog
         dlg = ResizeDialog(self.plot, new_size=original_size,
                            old_size=original_size,
@@ -892,11 +936,17 @@ class ImageFT(ObjectFT):
                             ).set_prop("display", active=prop)
         param = ResizeParam(_("Resize"))
         import scipy.ndimage as spi
+        
+        def func_obj(obj):
+            dx, dy = obj.pixel_spacing
+            if dx is not None and dy is not None:
+                obj.pixel_spacing = dx/param.zoom, dy/param.zoom
         self.compute_11("Zoom", lambda x, p:
                         spi.interpolation.zoom(x, p.zoom, order=p.order,
                                                mode=p.mode, cval=p.cval,
                                                prefilter=p.prefilter),
-                        param, suffix=lambda p: "zoom=%.3f" % p.zoom)
+                        param, suffix=lambda p: "zoom=%.3f" % p.zoom,
+                        func_obj=func_obj)
                         
     def extract_roi(self):
         class ROIParam(DataSet):
@@ -977,9 +1027,7 @@ class ImageFT(ObjectFT):
         imagenew = ImageParamNew(title=_("Create a new image"))
         rows = self._get_selected_rows()
         if rows:
-            data = self.objects[rows[-1]].data
-            imagenew.width = data.shape[1]
-            imagenew.height = data.shape[0]
+            imagenew.width, imagenew.height = self.objects[rows[-1]].size
         imagenew.title = "%s %d" % (imagenew.title, self.number+1)
         if not imagenew.edit(parent=self.parent()):
             return
@@ -1008,12 +1056,14 @@ class ImageFT(ObjectFT):
             image.title = filename
             image.data = data
             if osp.splitext(filename)[1].lower() == ".dcm":
-                import dicom
-                dcm = dicom.read_file(filename, stop_before_pixels=True)
-                image.metadata = {}
-                for attr_str in dir(dcm):
-                    if attr_str != 'GroupLength':
-                        image.metadata[attr_str] = getattr(dcm, attr_str)
+                try:
+                    # pydicom 1.0
+                    from pydicom import dicomio
+                except ImportError:
+                    # pydicom 0.9
+                    import dicom as dicomio
+                image.template = dicomio.read_file(filename,
+                                                   stop_before_pixels=True)
             self.add_object(image)
             
     def save_image(self):
@@ -1022,8 +1072,9 @@ class ImageFT(ObjectFT):
         for row in rows:
             obj = self.objects[row]
             from guiqwt.qthelpers import exec_image_save_dialog
-            filename = exec_image_save_dialog(obj.data, self, basedir='',
-                                              app_name=APP_NAME)
+            filename = exec_image_save_dialog(self, obj.data,
+                                              template=obj.template,
+                                              basedir='', app_name=APP_NAME)
             if filename:
                 os.chdir(osp.dirname(filename))
         
@@ -1060,8 +1111,11 @@ class DockablePlotWidget(DockableWidget):
 class DockableTabWidget(QTabWidget, DockableWidgetMixin):
     LOCATION = Qt.LeftDockWidgetArea
     def __init__(self, parent):
-        QTabWidget.__init__(self, parent)
-        DockableWidgetMixin.__init__(self, parent)
+        if PYQT5:
+            super(DockableTabWidget, self).__init__(parent, parent=parent)
+        else:
+            QTabWidget.__init__(self, parent)
+            DockableWidgetMixin.__init__(self, parent)
 
 
 try:
@@ -1081,8 +1135,15 @@ try:
             self.set_font(font)
             self.set_codecompletion_auto(True)
             self.set_calltips(True)
-            self.setup_calltips(size=600, font=font)
             self.setup_completion(size=(300, 180), font=font)
+            try:
+                self.traceback_available.connect(self.show_console)
+            except AttributeError:
+                pass
+            
+        def show_console(self):
+            self.dockwidget.raise_()
+            self.dockwidget.show()
 except ImportError:
     DockableConsole = None
 
@@ -1125,8 +1186,7 @@ class MainWindow(QMainWindow):
         self.imageft.setup(self.image_toolbar)
 
         for objectft in (self.signalft, self.imageft):
-            self.connect(objectft, SIGNAL("status_message(QString)"),
-                         status.showMessage)
+            objectft.SIG_STATUS_MESSAGE.connect(status.showMessage)
         
         # Main window widgets
         self.tabwidget = DockableTabWidget(self)
@@ -1142,12 +1202,11 @@ class MainWindow(QMainWindow):
         self.image_dock = self.add_dockwidget(self.imagewidget,
                                           title=_("Image visualization panel"))
         self.tabifyDockWidget(self.curve_dock, self.image_dock)
-        self.connect(self.tabwidget, SIGNAL('currentChanged(int)'),
-                     self.tab_index_changed)
-        self.connect(self.signalft, SIGNAL('object_added()'),
-                     lambda: self.tabwidget.setCurrentIndex(0))
-        self.connect(self.imageft, SIGNAL('object_added()'),
-                     lambda: self.tabwidget.setCurrentIndex(1))
+        self.tabwidget.currentChanged.connect(self.tab_index_changed)
+        self.signalft.SIG_OBJECT_ADDED.connect(
+                                    lambda: self.tabwidget.setCurrentIndex(0))
+        self.imageft.SIG_OBJECT_ADDED.connect(
+                                    lambda: self.tabwidget.setCurrentIndex(1))
         
         # File menu
         self.quit_action = create_action(self, _("Quit"), shortcut="Ctrl+Q",
@@ -1155,35 +1214,19 @@ class MainWindow(QMainWindow):
                                     tip=_("Quit application"),
                                     triggered=self.close)
         self.file_menu = self.menuBar().addMenu(_("File"))
-        self.connect(self.file_menu, SIGNAL("aboutToShow()"),
-                     self.update_file_menu)
+        self.file_menu.aboutToShow.connect(self.update_file_menu)
         
         # Edit menu
         self.edit_menu = self.menuBar().addMenu(_("&Edit"))
-        self.connect(self.edit_menu, SIGNAL("aboutToShow()"),
-                     self.update_edit_menu)
+        self.edit_menu.aboutToShow.connect(self.update_edit_menu)
         
         # Operation menu
         self.operation_menu = self.menuBar().addMenu(_("Operations"))
-        self.connect(self.operation_menu, SIGNAL("aboutToShow()"),
-                     self.update_operation_menu)
+        self.operation_menu.aboutToShow.connect(self.update_operation_menu)
         
         # Processing menu
         self.proc_menu = self.menuBar().addMenu(_("Processing"))
-        self.connect(self.proc_menu, SIGNAL("aboutToShow()"),
-                     self.update_proc_menu)
-        
-        # View menu
-        self.view_menu = view_menu = self.createPopupMenu()
-        view_menu.setTitle(_("&View"))
-        self.menuBar().addMenu(view_menu)
-        
-        # Help menu
-        help_menu = self.menuBar().addMenu("?")
-        about_action = create_action(self, _("About..."),
-                                     icon=get_std_icon('MessageBoxInformation'),
-                                     triggered=self.about)
-        add_actions(help_menu, (about_action,))
+        self.proc_menu.aboutToShow.connect(self.update_proc_menu)
         
         # Eventually add an internal console (requires 'spyderlib')
         self.sift_proxy = SiftProxy(self)
@@ -1200,10 +1243,25 @@ class MainWindow(QMainWindow):
                   "numpy as np, scipy.signal as sps, scipy.ndimage as spi"
             self.console = DockableConsole(self, namespace=ns, message=msg)
             self.add_dockwidget(self.console, _("Console"))
-            self.connect(self.console.interpreter.widget_proxy,
-                         SIGNAL("new_prompt(QString)"),
-                         lambda txt: self.refresh_lists())
+            try:
+                self.console.interpreter.widget_proxy.sig_new_prompt.connect(
+                                            lambda txt: self.refresh_lists())
+            except AttributeError:
+                print('sift: spyderlib is outdated', file=sys.stderr)
         
+        # View menu
+        self.view_menu = view_menu = self.createPopupMenu()
+        view_menu.setTitle(_("&View"))
+        self.menuBar().addMenu(view_menu)
+        
+        # Help menu
+        help_menu = self.menuBar().addMenu("?")
+        about_action = create_action(self, _("About..."),
+                                     icon=get_std_icon('MessageBoxInformation'),
+                                     triggered=self.about)
+        add_actions(help_menu, (about_action,))
+
+
         # Update selection dependent actions
         self.update_actions()
         
