@@ -88,11 +88,11 @@ Example
 The following example add all the existing tools to an `ImageWidget` object 
 for testing purpose:
 
-.. literalinclude:: ../guiqwt/tests/image_plot_tools.py
+.. literalinclude:: /../guiqwt/tests/image_plot_tools.py
    :start-after: SHOW
    :end-before: Workaround for Sphinx v0.6 bug: empty 'end-before' directive
 
-.. image:: images/screenshots/image_plot_tools.png
+.. image:: /images/screenshots/image_plot_tools.png
 
 
 Reference
@@ -254,10 +254,9 @@ import numpy as np
 import weakref
 import os.path as osp
 
-from guidata.qt.QtCore import Qt, QObject, SIGNAL, QPoint
+from guidata.qt.QtCore import Qt, QObject, QPointF, Signal
 from guidata.qt.QtGui import (QMenu, QActionGroup, QPrinter, QMessageBox,
-                              QPrintDialog, QFont, QAction, QToolButton,
-                              QKeySequence)
+                              QPrintDialog, QAction, QToolButton, QKeySequence)
 from guidata.qt.compat import getsavefilename, getopenfilename
 
 from guidata.qthelpers import get_std_icon, add_actions, add_separator
@@ -267,7 +266,6 @@ from guidata.dataset.dataitems import BoolItem, FloatItem
 from guidata.py3compat import is_text_string, to_text_string
 
 #Local imports
-from guiqwt.transitional import QwtPlotPrintFilter
 from guiqwt.config import _
 from guiqwt.events import (setup_standard_tool_filter, ObjectHandler,
                            KeyEventMatch, StandardKeyMatch,
@@ -283,12 +281,6 @@ from guiqwt.colormap import get_colormap_list, get_cmap, build_icon_from_cmap
 from guiqwt.interfaces import (IColormapImageItemType, IPlotManager,
                                IVoiImageItemType, IStatsImageItemType,
                                ICurveItemType)
-from guiqwt.signals import (SIG_VISIBILITY_CHANGED, SIG_CLICK_EVENT,
-                            SIG_START_TRACKING, SIG_STOP_NOT_MOVING,
-                            SIG_STOP_MOVING, SIG_MOVE, SIG_END_RECT,
-                            SIG_VALIDATE_TOOL, SIG_ITEMS_CHANGED,
-                            SIG_ITEM_SELECTION_CHANGED, SIG_APPLIED_MASK_TOOL,
-                            SIG_TOOL_JOB_FINISHED)
 from guiqwt.panels import ID_XCS, ID_YCS, ID_OCS, ID_ITEMLIST, ID_CONTRAST
 
 
@@ -367,12 +359,20 @@ class GuiTool(QObject):
 
 
 class InteractiveTool(GuiTool):
+    """Interactive tool base class"""
+    
     TITLE = None
     ICON = None
     TIP = None
     CURSOR = Qt.CrossCursor
     SWITCH_TO_DEFAULT_TOOL = False # switch to default tool when finished
 
+    #: Signal emitted by InteractiveTool when validating tool action
+    SIG_VALIDATE_TOOL = Signal()
+
+    #: Signal emitted by InteractiveTool when tool job is finished
+    SIG_TOOL_JOB_FINISHED = Signal()
+
     def __init__(self, manager, toolbar_id=DefaultToolbarID,
                  title=None, icon=None, tip=None,
                  switch_to_default_tool=None):
@@ -389,8 +389,8 @@ class InteractiveTool(GuiTool):
         if switch_to_default_tool is None:
             switch_to_default_tool = self.SWITCH_TO_DEFAULT_TOOL
         if switch_to_default_tool:
-            self.connect(self, SIG_TOOL_JOB_FINISHED,
-                         self.manager.activate_default_tool)
+            self.SIG_TOOL_JOB_FINISHED.connect(
+                                        self.manager.activate_default_tool)
                         
     def create_action(self, manager):
         """Create and return tool's action"""
@@ -399,8 +399,7 @@ class InteractiveTool(GuiTool):
         action.setCheckable(True)
         group = self.manager.get_tool_group("interactive")
         group.addAction(action)
-        QObject.connect(group, SIGNAL("triggered(QAction*)"),
-                        self.interactive_triggered)
+        group.triggered.connect(self.interactive_triggered)
         return action
 
     def cursor(self):
@@ -440,8 +439,8 @@ class InteractiveTool(GuiTool):
         self.action.setChecked(False)
 
     def validate(self, filter, event):
-        self.emit(SIG_VALIDATE_TOOL, filter)
-        self.emit(SIG_TOOL_JOB_FINISHED)
+        self.SIG_VALIDATE_TOOL.emit(filter)
+        self.SIG_TOOL_JOB_FINISHED.emit()
 
 
 class SelectTool(InteractiveTool):
@@ -509,10 +508,10 @@ class SelectPointTool(InteractiveTool):
         start_state = filter.new_state()
         # Bouton gauche :
         handler = QtDragHandler(filter, Qt.LeftButton, start_state=start_state)
-        self.connect(handler, SIG_START_TRACKING, self.start)
-        self.connect(handler, SIG_MOVE, self.move)
-        self.connect(handler, SIG_STOP_NOT_MOVING, self.stop)
-        self.connect(handler, SIG_STOP_MOVING, self.stop)
+        handler.SIG_START_TRACKING.connect(self.start)
+        handler.SIG_MOVE.connect(self.move)
+        handler.SIG_STOP_NOT_MOVING.connect(self.stop)
+        handler.SIG_STOP_MOVING.connect(self.stop)
         return setup_standard_tool_filter(filter, start_state)
 
     def start(self, filter, event):
@@ -603,10 +602,10 @@ class MultiLineTool(InteractiveTool):
         filter.add_event(start_state,
                          KeyEventMatch( (Qt.Key_Backspace, Qt.Key_Escape,) ),
                          self.cancel_point, start_state)
-        self.connect(handler, SIG_START_TRACKING, self.mouse_press)
-        self.connect(handler, SIG_MOVE, self.move)
-        self.connect(handler, SIG_STOP_NOT_MOVING, self.mouse_release)
-        self.connect(handler, SIG_STOP_MOVING, self.mouse_release)
+        handler.SIG_START_TRACKING.connect(self.mouse_press)
+        handler.SIG_MOVE.connect(self.move)
+        handler.SIG_STOP_NOT_MOVING.connect(self.mouse_release)
+        handler.SIG_STOP_MOVING.connect(self.mouse_release)
         return setup_standard_tool_filter(filter, start_state)
 
     def validate(self, filter, event):
@@ -708,7 +707,7 @@ class LabelTool(InteractiveTool):
         filter = baseplot.filter
         start_state = filter.new_state()
         handler = ClickHandler(filter, Qt.LeftButton, start_state=start_state)
-        self.connect(handler, SIG_CLICK_EVENT, self.add_label_to_plot)
+        handler.SIG_CLICK_EVENT.connect(self.add_label_to_plot)
         return setup_standard_tool_filter(filter, start_state)
 
     def add_label_to_plot(self, filter, event):
@@ -730,7 +729,7 @@ class LabelTool(InteractiveTool):
             if self.handle_label_cb is not None:
                 self.handle_label_cb(label)
             plot.replot()
-            self.emit(SIG_TOOL_JOB_FINISHED)
+            self.SIG_TOOL_JOB_FINISHED.emit()
         
 
 class RectangularActionTool(InteractiveTool):
@@ -792,7 +791,7 @@ class RectangularActionTool(InteractiveTool):
         shape, h0, h1 = self.get_shape()
         handler.set_shape(shape, h0, h1, self.setup_shape,
                           avoid_null_shape=self.AVOID_NULL_SHAPE)
-        self.connect(handler, SIG_END_RECT, self.end_rect)
+        handler.SIG_END_RECT.connect(self.end_rect)
         return setup_standard_tool_filter(filter, start_state)
 
     def end_rect(self, filter, p0, p1):
@@ -800,10 +799,10 @@ class RectangularActionTool(InteractiveTool):
         if self.fix_orientation:
             left, right = min(p0.x(), p1.x()), max(p0.x(), p1.x())
             top, bottom = min(p0.y(), p1.y()), max(p0.y(), p1.y())
-            self.action_func(plot, QPoint(left, top), QPoint(right, bottom))
+            self.action_func(plot, QPointF(left, top), QPointF(right, bottom))
         else:
             self.action_func(plot, p0, p1)
-        self.emit(SIG_TOOL_JOB_FINISHED)
+        self.SIG_TOOL_JOB_FINISHED.emit()
         if self.switch_to_default_tool:
             shape = self.get_last_final_shape()
             plot.set_active_item(shape)
@@ -1125,9 +1124,9 @@ class BaseCursorTool(InteractiveTool):
         # Bouton gauche :
         self.handler = QtDragHandler(filter, Qt.LeftButton,
                                      start_state=start_state )
-        self.connect(self.handler, SIG_MOVE, self.move)
-        self.connect(self.handler, SIG_STOP_NOT_MOVING, self.end_move)
-        self.connect(self.handler, SIG_STOP_MOVING, self.end_move)
+        self.handler.SIG_MOVE.connect(self.move)
+        self.handler.SIG_STOP_NOT_MOVING.connect(self.end_move)
+        self.handler.SIG_STOP_MOVING.connect(self.end_move)
         return setup_standard_tool_filter(filter, start_state)
 
     def move(self, filter, event):
@@ -1146,7 +1145,7 @@ class BaseCursorTool(InteractiveTool):
             assert self.shape.plot() == filter.plot
             filter.plot.add_item_with_z_offset(self.shape, SHAPE_Z_OFFSET)
             self.shape = None
-            self.emit(SIG_TOOL_JOB_FINISHED)
+            self.SIG_TOOL_JOB_FINISHED.emit()
 
 class HRangeTool(BaseCursorTool):
     TITLE = _("Horizontal selection")
@@ -1254,6 +1253,7 @@ class DummySeparatorTool(GuiTool):
 
 class CommandTool(GuiTool):
     """Base class for command tools: action, context menu entry"""
+    CHECKABLE = False
     def __init__(self, manager, title, icon=None, tip=None,
                  toolbar_id=DefaultToolbarID):
         self.title = title
@@ -1267,7 +1267,8 @@ class CommandTool(GuiTool):
     def create_action(self, manager):
         """Create and return tool's action"""
         return manager.create_action(self.title, icon=self.icon,
-                                     tip=self.tip, triggered=self.activate)
+                                     tip=self.tip, triggered=self.activate,
+                                     checkable=self.CHECKABLE)
 
     def setup_context_menu(self, menu, plot):
         menu.addAction(self.action)
@@ -1284,12 +1285,10 @@ class CommandTool(GuiTool):
         else:
             self.action.setEnabled(False)
 
-
 class ToggleTool(CommandTool):
+    CHECKABLE = True
     def __init__(self, manager, title, icon=None, tip=None, toolbar_id=None):
         super(ToggleTool, self).__init__(manager, title, icon, tip, toolbar_id)
-        # Creation de l'action
-        self.action.setCheckable(True)
 
 
 class BasePlotMenuTool(CommandTool):
@@ -1457,8 +1456,8 @@ class PanelTool(ToggleTool):
     panel_name = None
     def __init__(self, manager):
         super(PanelTool, self).__init__(manager, self.panel_name)
-        self.connect(manager.get_panel(self.panel_id),
-                     SIG_VISIBILITY_CHANGED, self.action.setChecked)
+        manager.get_panel(self.panel_id).SIG_VISIBILITY_CHANGED.connect(
+                                                        self.action.setChecked)
 
     def activate_command(self, plot, checked):
         """Activate tool"""
@@ -1531,10 +1530,11 @@ class CopyToClipboardTool(CommandTool):
         plot.copy_to_clipboard()
 
 
-def save_snapshot(plot, p0, p1):
+def save_snapshot(plot, p0, p1, new_size=None):
     """
     Save rectangular plot area
-    p0, p1: resp. top left and bottom right points (QPoint objects)
+    p0, p1: resp. top left and bottom right points (`QPointF` objects)
+    new_size: destination image size (tuple: (width, height))
     """
     from guiqwt.image import (get_image_from_plot, get_plot_qrect,
                               get_items_in_rectangle,
@@ -1547,10 +1547,12 @@ def save_snapshot(plot, p0, p1):
         return
     src_x, src_y, src_w, src_h = get_plot_qrect(plot, p0, p1).getRect()
     original_size = compute_trimageitems_original_size(items, src_w, src_h)
-    screen_size = (p1.x()-p0.x()+1, p1.y()-p0.y()+1)
+
+    if new_size is None:
+        new_size = (p1.x()-p0.x()+1, p1.y()-p0.y()+1) # Screen size
     
     from guiqwt.widgets.resizedialog import ResizeDialog
-    dlg = ResizeDialog(plot, new_size=screen_size, old_size=original_size,
+    dlg = ResizeDialog(plot, new_size=new_size, old_size=original_size,
                        text=_("Destination size:"))
     if not dlg.exec_():
         return
@@ -1619,8 +1621,13 @@ def save_snapshot(plot, p0, p1):
     elif ext.lower() == ".png":
         options.update(dict(dtype=np.uint8, max_range=True))
     elif ext.lower() == ".dcm":
-        import dicom
-        model_dcm = dicom.read_file(model_fname)
+        try:
+            # pydicom 1.0
+            from pydicom import dicomio
+        except ImportError:
+            # pydicom 0.9
+            import dicom as dicomio
+        model_dcm = dicomio.read_file(model_fname)
         try:
             ps_attr = 'ImagerPixelSpacing'
             ps_x, ps_y = getattr(model_dcm, ps_attr)
@@ -1680,29 +1687,6 @@ class RotateCropTool(CommandTool):
         self.action.setEnabled(status)
 
 
-class PrintFilter(QwtPlotPrintFilter):
-    def __init__(self):
-        super(PrintFilter, self).__init__()
-
-    def color(self, c, item):
-        if not (self.options() & QwtPlotPrintFilter.CanvasBackground):
-            if item == QwtPlotPrintFilter.MajorGrid:
-                return Qt.darkGray
-            elif item == QwtPlotPrintFilter.MinorGrid:
-                return Qt.gray
-        if item == QwtPlotPrintFilter.Title:
-            return Qt.red
-        elif item == QwtPlotPrintFilter.AxisScale:
-            return Qt.green
-        elif item == QwtPlotPrintFilter.AxisTitle:
-            return Qt.blue
-        return c
-
-    def font(self, f, _):
-        result = QFont(f)
-        result.setPointSize(int(f.pointSize()*1.25))
-        return result
-
 class PrintTool(CommandTool):
     def __init__(self, manager, toolbar_id=DefaultToolbarID):
         super(PrintTool, self).__init__(manager, _("Print..."),
@@ -1717,15 +1701,14 @@ class PrintTool(CommandTool):
         ok = dialog.exec_()
         sys.stdin, sys.stdout, sys.stderr = saved_in, saved_out, saved_err
         if ok:
-            filter = PrintFilter()
-            if (QPrinter.GrayScale == printer.colorMode()):
-                filter.setOptions(QwtPlotPrintFilter.PrintAll
-                                  & ~QwtPlotPrintFilter.PrintBackground
-                                  | QwtPlotPrintFilter.PrintFrameWithScales)
-            plot.print_(printer, filter)
+            plot.print_(printer)
 
 
 class OpenFileTool(CommandTool):
+    
+    #: Signal emitted by OpenFileTool when a file was opened (arg: filename)
+    SIG_OPEN_FILE = Signal(str)
+
     def __init__(self, manager, title=_("Open..."), formats='*.*',
                  toolbar_id=DefaultToolbarID):
         super(OpenFileTool, self).__init__(manager, title,
@@ -1748,7 +1731,7 @@ class OpenFileTool(CommandTool):
         """Activate tool"""
         filename = self.get_filename(plot)
         if filename:
-            self.emit(SIGNAL("openfile(QString*)"), filename)
+            self.SIG_OPEN_FILE.emit(filename)
 
 
 class SaveItemsTool(CommandTool):
@@ -1927,7 +1910,7 @@ def export_curve_data(item):
 def export_image_data(item):
     """Export image item data to file"""
     from guiqwt.qthelpers import exec_image_save_dialog
-    exec_image_save_dialog(item.data, item.plot())
+    exec_image_save_dialog(item.plot(), item.data)
 
 class ExportItemDataTool(ItemManipulationBaseTool):
     TITLE = _("Export data...")
@@ -2069,8 +2052,7 @@ class ColormapTool(CommandTool):
             icon = build_icon_from_cmap(cmap)
             action = menu.addAction(icon, cmap_name)
             action.setEnabled(True)
-        QObject.connect(menu, SIGNAL("triggered(QAction*)"),
-                        self.activate_cmap)
+        menu.triggered.connect(self.activate_cmap)
         return menu
 
     def activate_command(self, plot, checked):
@@ -2113,6 +2095,10 @@ class ColormapTool(CommandTool):
 
 
 class ImageMaskTool(CommandTool):
+    
+    #: Signal emitted by ImageMaskTool when mask was applied
+    SIG_APPLIED_MASK_TOOL = Signal()
+
     def __init__(self, manager, toolbar_id=DefaultToolbarID):
         self._mask_shapes = {}
         self._mask_already_restored = {}
@@ -2174,9 +2160,9 @@ class ImageMaskTool(CommandTool):
     def register_plot(self, baseplot):
         super(ImageMaskTool, self).register_plot(baseplot)
         self._mask_shapes.setdefault(baseplot, [])
-        self.connect(baseplot, SIG_ITEMS_CHANGED, self.items_changed)
-        self.connect(baseplot, SIG_ITEM_SELECTION_CHANGED,
-                     self.item_selection_changed)
+        baseplot.SIG_ITEMS_CHANGED.connect(self.items_changed)
+        baseplot.SIG_ITEM_SELECTION_CHANGED.connect(
+                                                self.item_selection_changed)
 
     def show_mask(self, state):
         if self.masked_image is not None:
@@ -2197,7 +2183,7 @@ class ImageMaskTool(CommandTool):
                                                      inside=inside)
         self.masked_image.set_mask(mask)
         plot.replot()
-        self.emit(SIG_APPLIED_MASK_TOOL)
+        self.SIG_APPLIED_MASK_TOOL.emit()
         
     def remove_all_shapes(self):
         message = _("Do you really want to remove all masking shapes?")
